/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_NOTATIONERASER_H_
#define _RG_NOTATIONERASER_H_

#include "NotationTool.h"
#include <tqstring.h>
#include "base/Event.h"


class TQMouseEvent;


namespace Rosegarden
{

class ViewElement;
class NotationView;


/**
 * This tool will erase a note on mouse click events
 */
class NotationEraser : public NotationTool
{
    TQ_OBJECT
  

    friend class NotationToolBox;

public:

    virtual void ready();

    virtual void handleLeftButtonPress(timeT,
                                       int height,
                                       int staffNo,
                                       TQMouseEvent*,
                                       ViewElement* el);
    static const TQString ToolName;

public slots:
    void slotToggleRestCollapse();
    
    void slotInsertSelected();
    void slotSelectSelected();

protected:
    NotationEraser(NotationView*);

    //--------------- Data members ---------------------------------

    bool m_collapseRest;
};


}

#endif
